# IO Module / 入出力モジュール

The `wandas.io` module provides reading and writing capabilities for various file formats.
`wandas.io` モジュールは、様々なファイル形式の読み書き機能を提供します。

## File Readers / ファイルリーダー

Provides functionality to read data from various file formats.
様々なファイル形式からデータを読み込む機能を提供します。

::: wandas.io.readers

## WAV File IO / WAVファイル入出力

Provides functions for reading and writing WAV files.
WAVファイルの読み書き機能を提供します。

::: wandas.io.wav_io

## WDF File IO / WDFファイル入出力

Provides functions for reading and writing WDF (Wandas Data File) format, which enables complete preservation including metadata.
WDF（Wandas Data File）形式の読み書き機能を提供します。このフォーマットはメタデータを含む完全な保存が可能です。

::: wandas.io.wdf_io
